@@ -3,7 +3,8 @@ from typing import List
 from aiohttp import ClientSession
 
 from .baseApi import BaseAPI
-from .device import _LOGGER, Device, ReadOnlyClass
+from .const import ReadOnlyClass
+from .device import _LOGGER, Device
 
 
 class CMI(BaseAPI, metaclass=ReadOnlyClass):
